# Karol-Oke

A simple Karaoke framework to make your party  (Karol-Okê)

## Main objetive

Offer a simple way to use a video set and a simple user interface for Karoke party.

## Major features

- [ ] 

## Installation

## Documentation

Getting started using the `docs` folder for additional documentation
